==> ejc-filesystem-api-3.0.0-20241021.065747-21-sources.jar: com/ejianc/business/filesystem/file/vo/FileRecordVO.java <==
package com.ejianc.business.filesystem.file.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 文件记录表
 * 
 * @author generator
 * 
 */
public class FileRecordVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long billId; // 单据id
    private String fileType; // 文件类型
    private String fileName; // 文件名称
    private String filePath; // 文件地址
    private String createUserName; // 编制人
    private String updateUserName; // 修改者
    private String remark; // 备注
    

    public Long getBillId() {
        return billId;
    }

    public void setBillId(Long billId) {
        this.billId = billId;
    }
    public String getFileType() {
        return fileType;
    }

    public void setFileType(String fileType) {
        this.fileType = fileType;
    }
    public String getFileName() {
        return fileName;
    }

    public void setFileName(String fileName) {
        this.fileName = fileName;
    }
    public String getFilePath() {
        return filePath;
    }

    public void setFilePath(String filePath) {
        this.filePath = filePath;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    
}

==> ejc-filesystem-api-3.0.0-20250821.083512-47-sources.jar: com/ejianc/business/filesystem/file/vo/FileRecordVO.java <==
package com.ejianc.business.filesystem.file.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 文件记录表
 * 
 * @author generator
 * 
 */
public class FileRecordVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long billId; // 单据id
    private String fileType; // 文件类型
    private String fileName; // 文件名称
    private String filePath; // 文件地址
    private String createUserName; // 编制人
    private String updateUserName; // 修改者
    private String remark; // 备注
    private Integer isCopy; // 是否复制（1是，0否）


    public Integer getIsCopy() {
        return isCopy;
    }

    public void setIsCopy(Integer isCopy) {
        this.isCopy = isCopy;
    }

    public Long getBillId() {
        return billId;
    }

    public void setBillId(Long billId) {
        this.billId = billId;
    }
    public String getFileType() {
        return fileType;
    }

    public void setFileType(String fileType) {
        this.fileType = fileType;
    }
    public String getFileName() {
        return fileName;
    }

    public void setFileName(String fileName) {
        this.fileName = fileName;
    }
    public String getFilePath() {
        return filePath;
    }

    public void setFilePath(String filePath) {
        this.filePath = filePath;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    
}
